@@ -103,6 +103,13 @@ plot.ceteris_paribus_explainer <- function(x, ...,
 
   all_profiles$`_ids_` <- factor(all_profiles$`_ids_`)
 
+  # fix for https://github.com/ModelOriented/ingredients/issues/123 set colors to _label_ with multiple models
+  if (color == "#46bac2" && length(unique(all_profiles$`_label_`)) > 1)
+    color <- "_label_"
+  if (color == "#46bac2" && length(unique(all_profiles$`_ids_`)) > 1)
+    color <- "_ids_"
+
+
   # extract labels to use in the default subtitle
   if (is.null(subtitle)) {
     labels <- paste0(unique(all_profiles$`_label_`), collapse = ", ")
@@ -216,18 +223,21 @@ plot_categorical_ceteris_paribus <- function(all_profiles, selected_observation,
   })
   # transformed data frame
   selected_cp_flat <- do.call(rbind, lsc)
+  `_yhat_` <- NULL
 
   # is color a variable or literal?
   is_color_a_variable <- color %in% c(variables, "_label_", "_vname_", "_ids_")
   if (is_color_a_variable) {
     selected_cp_flat$`_ids_color_` <- paste(selected_cp_flat[,"_ids_"], selected_cp_flat[,color], sep = "_")
     pl <- ggplot(selected_cp_flat, aes_string("`_x_`", "`_yhat_`", group = "`_ids_color_`", color = paste0("`",color,"`"))) +
-      geom_line(size = size/2, alpha = alpha) +
+      geom_errorbar(aes(ymin = `_yhat_`, ymax = `_yhat_`), size = size/2, alpha = alpha) +
+#      geom_line(size = size/2, alpha = alpha) +
       geom_point(data = selected_cp_flat[selected_cp_flat$`_real_point_`, ],
                  size = size, alpha = alpha)
   } else {
     pl <- ggplot(selected_cp_flat, aes_string("`_x_`", "`_yhat_`", group = "`_ids_`")) +
-      geom_line(size = size/2, alpha = alpha, color = color) +
+      geom_errorbar(aes(ymin = `_yhat_`, ymax = `_yhat_`), size = size/2, alpha = alpha, color = color) +
+      #      geom_line(size = size/2, alpha = alpha) +
       geom_point(data = selected_cp_flat[selected_cp_flat$`_real_point_`, ],
                  color = color, size = size, alpha = alpha)
   }
